<?php

namespace Drupal\lb_auto_translation\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Module handler service object.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typedConfigManager, EntityTypeManagerInterface $entity_type_manager, ModuleHandlerInterface $moduleHandler) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->entityTypeManager = $entity_type_manager;
    $this->moduleHandler = $moduleHandler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('entity_type.manager'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return ['lb_auto_translation.settings'];
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'lb_auto_translation_settings';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('lb_auto_translation.settings');
    $enabled_content_types = $config->get('content_types');
    $options = [];

    if ($this->moduleHandler->moduleExists('block_content')) {
      $block_types = $this->entityTypeManager
        ->getStorage('block_content_type')
        ->loadMultiple();
      if ($block_types) {
        foreach ($block_types as $type) {
          if ($type->id()) {
            $options[$type->id()] = $type->label();
          }
        }
      }
    }

    $form['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Enabled Content Types'),
      '#description' => $this->t('Define what content types will be enabled for auto translation.'),
      '#default_value' => $enabled_content_types,
      '#options' => $options,
    ];

    return parent::buildForm($form, $form_state);
  }
}
