<?php

namespace Drupal\lb_auto_translation\Traits;

/**
 * Trait as a helper for translation HTML strings.
 */
trait TranslationHtmlTrait {

  /**
   * Protect HTML tags and special chars from translator.
   *
   * @param string $text
   *   String to be translated.
   *
   * @return array
   *   Protected text with placeholders and list of replaced HTML tags.
   */
  public function protectHtmlTags(string $text):array {
    $tags = [];
    $protectedText = preg_replace_callback('/(<[^>]+>)|&([a-z]{2,8}\d{0,2});/', function ($matches) use (&$tags) {
      $tag = $matches[0];
      $key = '[#' . count($tags) . ']';
      $tags[count($tags)] = $tag;
      return $key;
    }, $text);

    return [$protectedText, $tags];
  }

  /**
   * Replace placeholders with real HTML tags.
   *
   * @param string $text
   *   String with placeholders.
   * @param array $tags
   *   List of HTML tags for replacement.
   *
   * @return string
   *   Result string with HTML tags.
   */
  public function restoreHtmlTags(string $text, array $tags):string {
    return preg_replace_callback('/\[#(\d+)\]/', function ($matches) use ($tags) {
      return $tags[$matches[1]] ?? $matches[0];
    }, $text);
  }
}
